@@ -889,9 +889,9 @@ class WordToken(models.Model):
         if form['phonotactic'] == 'VB':
             outline['SPhoneProb'],outline['BiPhoneProb'] = self.WordType.getPhonoProb()
         elif form['phonotactic'] == 'B':
-            outline['BlickPhono'] = getPhonoProb(self.WordType.getStrUR(),use_blick=True,no_stress=True)
+            outline['BlickPhono'] = getPhonotacticProb(self.WordType.getStrUR(),use_blick=True,no_stress=True)
         elif form['phonotactic'] == 'VP':
-            outline['SPhoneProb'],outline['BiPhoneProb'] = getPhonoProb(self.WordType.getStrUR(),use_blick=False,no_stress=True)
+            outline['SPhoneProb'],outline['BiPhoneProb'] = getPhonotacticProb(self.WordType.getStrUR(),use_blick=False,no_stress=True)
         if form['prev_sem_pred']:
             outline['PrevSemPred'] = self.getPrevSemPred()
             outline['ImmedSemPred'] = self.getImmediateSemPred()
